MobxObservableWatcher class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rebuildCallback ↔ void Function(BuildContext context, Object observable)
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ContextWatcherObservableType
-
finalinherited
Methods
-
createSubscription<
T> (BuildContext context, Observable observable) → ContextWatchSubscription -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuildIfNeeded(
BuildContext context, Observable observable) → void -
Triggers a rebuild of the
contextif it is interested in theobservablevalue change notification.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → MobxObservableWatcher
-
final